pub fn interpret_repair_replay(
entries: &[LedgerEntry],
) -> Result<RepairReplayInterpretation, String>Expand description
Replays a repair ledger into the reference replay state.
pub fn interpret_repair_replay(
entries: &[LedgerEntry],
) -> Result<RepairReplayInterpretation, String>Replays a repair ledger into the reference replay state.